@@ -2,19 +2,23 @@ import numpy as np
 from scipy.signal import medfilt2d, convolve2d
 
 
-def nans(*args, **kwargs):
+def _nans(*args, **kwargs):
     out = np.empty(*args, **kwargs)
-    out[:] = np.NaN
-    return out
+    if np.issubdtype(out.flatten()[0], np.integer):
+        out[:] = 0
+        return out
+    else:
+        out[:] = np.nan
+        return out
 
 
-def nans_like(*args, **kwargs):
+def _nans_like(*args, **kwargs):
     out = np.empty_like(*args, **kwargs)
-    out[:] = np.NaN
+    out[:] = np.nan
     return out
 
 
-def find(arr):
+def _find(arr):
     return np.nonzero(np.ravel(arr))[0]
 
 
@@ -23,10 +27,8 @@ def detrend(arr, axis=-1, in_place=False):
 
     Parameters
     ----------
-
     arr : array_like
        The array from which to remove a linear trend.
-
     axis : int
        The axis along which to operate.
 
@@ -44,10 +46,10 @@ def detrend(arr, axis=-1, in_place=False):
     sz = np.ones(arr.ndim, dtype=int)
     sz[axis] = arr.shape[axis]
     x = np.arange(sz[axis], dtype=np.float_).reshape(sz)
-    x -= x.mean(axis=axis, keepdims=True)
-    arr -= arr.mean(axis=axis, keepdims=True)
-    b = (x * arr).mean(axis=axis, keepdims=True) / (x ** 2).mean(axis=axis,
-                                                                 keepdims=True)
+    x -= np.nanmean(x, axis=axis, keepdims=True)
+    arr -= np.nanmean(arr, axis=axis, keepdims=True)
+    b = np.nanmean((x * arr), axis=axis, keepdims=True) / \
+        np.nanmean((x ** 2), axis=axis, keepdims=True)
     arr -= b * x
     return arr
 
@@ -57,7 +59,7 @@ def group(bl, min_length=0):
 
     Parameters
     ----------
-    bl : np.ndarray(dtype='bool')
+    bl : |np.ndarray| (dtype='bool')
       The input boolean array.
     min_length : int (optional)
       Specifies the minimum number of continuos points to consider a
@@ -71,7 +73,6 @@ def group(bl, min_length=0):
 
     Notes
     -----
-
     This function has funny behavior for single points.  It will
     return the same two indices for the beginning and end.
 
@@ -101,82 +102,29 @@ def group(bl, min_length=0):
     return out[:idx]
 
 
-class delta(object):
-
-    """
-    delta objects find indices in an input array of `data` that fall
-    within a distance `delta` from a `value`
-
-    Parameters
-    ----------
-
-    data : np.ndarray
-      The data that should be indexed.
-
-    delta : float
-      The distance from `val` that the data will be indexed as True.
-
-    """
-
-    @property
-    def shape(self,):
-        return self.data.shape
-
-    def __init__(self, data, delta):
-        """
-        Create a delta object for *data* with delta *delta*.
-        """
-        self.data = data
-        self.delta = delta
-
-    def __call__(self, val):
-        """
-        Return the indices of `data` that fall within `val`- `delta` to
-        `val` + `delta`.
-
-        Parameters
-        ----------
-
-        val : float
-          The value at the center of the range.
-
-        """
-        return (val - self.delta < self.data) & (self.data < val + self.delta)
-
-    def abs(self, val):
-        return ((val - self.delta < np.abs(self.data)) &
-                (np.abs(self.data) < val + self.delta))
-
-
 def slice1d_along_axis(arr_shape, axis=0):
     """
-    Return an iterator object for looping over 1-D slices, along *axis*, of
+    Return an iterator object for looping over 1-D slices, along ``axis``, of
     an array of shape arr_shape.
 
     Parameters
     ----------
     arr_shape : tuple,list
-        Shape of the array over which the slices will be made.
+      Shape of the array over which the slices will be made.
     axis : integer
-        Axis along which `arr` is sliced.
+      Axis along which `arr` is sliced.
 
     Returns
     -------
-    Iterator object.
-    The iterator object returns slice objects which slices arrays of
-    shape arr_shape into 1-D arrays.
-
-    See Also
-    --------
-    apply_over_axis : Apply a function to 1-D slices along the given axis.
-    apply_over_axes : Apply a function repeatedly over multiple axes.
+    Iterator : object
+      The iterator object returns slice objects which slices arrays of
+      shape arr_shape into 1-D arrays.
 
     Examples
     --------
-
-    >>> out=np.empty(replace(arr.shape,0,1))
-    >>> for slc in slice1d_along_axis(arr.shape,axis=0):
-            out[slc]=my_1d_function(arr[slc])
+    >> out=np.empty(replace(arr.shape,0,1))
+    >> for slc in slice1d_along_axis(arr.shape,axis=0):
+    >>     out[slc]=my_1d_function(arr[slc])
 
     """
     nd = len(arr_shape)
@@ -205,32 +153,26 @@ def slice1d_along_axis(arr_shape, axis=0):
 
 
 def fillgaps(a, maxgap=np.inf, dim=0, extrapFlg=False):
-    """
-    Linearly fill NaN value in an array.
+    """Linearly fill NaN value in an array.
 
     Parameters
     ----------
     a : |np.ndarray|
       The array to be filled.
-
     maxgap : |np.ndarray| (optional: inf)
       The maximum gap to fill.
-
     dim : int (optional: 0)
       The dimension to operate along.
-
     extrapFlg : bool (optional: False)
       Whether to extrapolate if NaNs are found at the ends of the
       array.
 
     See Also
-    =====
-
-    interpgaps : Linearly interpolates in time.
+    --------
+    dolfyn.tools.misc.interpgaps : Linearly interpolates in time.
 
     Notes
-    =====
-
+    -----
     This function interpolates assuming spacing/timestep between
     successive points is constant. If the spacing is not constant, use
     interpgaps.
@@ -255,10 +197,7 @@ def fillgaps(a, maxgap=np.inf, dim=0, extrapFlg=False):
     indlist = list(range(nd))
     indlist.remove(dim)
     i[dim] = slice(None, None)
-    # outshape = np.asarray(a.shape).take(indlist)
-    # Ntot = np.product(outshape)
     i.put(indlist, ind)
-    # k = 0
 
     gd = np.nonzero(~np.isnan(a))[0]
 
@@ -278,34 +217,31 @@ def fillgaps(a, maxgap=np.inf, dim=0, extrapFlg=False):
                      (np.arange(0, ii.__len__()) + 1) /
                      (ii.__len__() + 1) + a[gd[inds[i2]]]).astype(a.dtype)
 
+    return a
+
 
 def interpgaps(a, t, maxgap=np.inf, dim=0, extrapFlg=False):
     """
     Fill gaps (NaN values) in ``a`` by linear interpolation along
-    dimension DIM with the point spacing specified in ``t``.
+    dimension ``dim`` with the point spacing specified in ``t``.
 
     Parameters
-    ==========
+    ----------
     a : |np.ndarray|
       The array containing NaN values to be filled.
-
     t : |np.ndarray| (len(t) == a.shape[dim])
-      The grid of the points in ``a``.
-
+      Independent variable of the points in ``a``, e.g. timestep
     maxgap : |np.ndarray| (optional: inf)
       The maximum gap to fill.
-
     dim : int (optional: 0)
       The dimension to operate along.
-
     extrapFlg : bool (optional: False)
       Whether to extrapolate if NaNs are found at the ends of the
       array.
 
     See Also
-    =====
-
-    fillgaps : Linearly interpolates in array-index space.
+    --------
+    dolfyn.tools.misc.fillgaps : Linearly interpolates in array-index space.
 
     """
 
@@ -314,8 +250,8 @@ def interpgaps(a, t, maxgap=np.inf, dim=0, extrapFlg=False):
         for inds in slice1d_along_axis(a.shape, dim):
             interpgaps(a[inds], t, maxgap, 0, extrapFlg)
         return
-    #
-    gd = find(~np.isnan(a))
+
+    gd = _find(~np.isnan(a))
 
     # Here we extrapolate the ends, if necessary:
     if extrapFlg and gd.__len__() > 0:
@@ -326,8 +262,8 @@ def interpgaps(a, t, maxgap=np.inf, dim=0, extrapFlg=False):
 
     # Here is the main loop
     if gd.__len__() > 1:
-        inds = find((1 < np.diff(gd)) &
-                    (np.diff(gd) <= maxgap + 1))
+        inds = _find((1 < np.diff(gd)) &
+                     (np.diff(gd) <= maxgap + 1))
         for i2 in range(0, inds.__len__()):
             ii = np.arange(gd[inds[i2]] + 1, gd[inds[i2] + 1])
             ti = (t[ii] - t[gd[inds[i2]]]) / np.diff(t[[gd[inds[i2]],
@@ -335,15 +271,35 @@ def interpgaps(a, t, maxgap=np.inf, dim=0, extrapFlg=False):
             a[ii] = (np.diff(a[gd[[inds[i2], inds[i2] + 1]]]) * ti +
                      a[gd[inds[i2]]]).astype(a.dtype)
 
+    return a
+
 
 def medfiltnan(a, kernel, thresh=0):
     """
-    Do a running median filter of the data.
+    Do a running median filter of the data. Regions where more than 
+    ``thresh`` fraction of the points are NaN are set to NaN.
 
-    Regions where more than *thresh* fraction of the points are NaN
-    are set to NaN.
+    Parameters
+    ----------
+    a : |np.ndarray|
+      2D array containing data to be filtered.
+    kernel_size : |np.ndarray| or list, optional
+      A scalar or a list of length 2, giving the size of the median 
+      filter window in each dimension. Elements of kernel_size should 
+      be odd. If kernel_size is a scalar, then this scalar is used as 
+      the size in each dimension.
+    thresh : int
+      Maximum gap in *a* to filter over
+
+    Returns
+    -------
+    out : |np.ndarray|
+      2D array of same size containing filtered data
+
+    See Also
+    --------
+    scipy.signal.medfilt2d
 
-    Currently only work for vectors.
     """
     flag_1D = False
     if a.ndim == 1:
@@ -363,11 +319,32 @@ def medfiltnan(a, kernel, thresh=0):
     return out
 
 
-def degN2cartDeg(angN,):
+def convert_degrees(deg, tidal_mode=True):
     """
-    Convert degrees True North to 'cartesian Degrees'
-    (counter-clockwise from the East).
+    Converts between the 'cartesian angle' (counter-clockwise from East) and
+    the 'polar angle' in (degrees clockwise from North)
+
+    Parameters
+    ----------
+    deg: float or array-like
+      Number or array in 'degrees CCW from East' or 'degrees CW from North'
+    tidal_mode : bool
+      If true, range is set from 0 to +/-180 degrees. If false, range is 0 to 
+      360 degrees
+
+    Returns
+    -------
+    out : float or array-like
+      Input data transformed to 'degrees CW from North' or 
+      'degrees CCW from East', respectively (based on `deg`)
+
+    Notes
+    -----
+    The same algorithm is used to convert back and forth between 'CCW from E' 
+    and 'CW from N'
+
     """
-    out = 90 - angN
-    out[out < -180] += 360
+    out = -(deg - 90) % 360
+    if tidal_mode:
+        out[out > 180] -= 360
     return out
